==> maegym_0.4.5-1.tar.gz: maegym-0.4.5/src/usr/lib/python2.5/site-packages/maegym/welcome_window.py <==
###############################################################################
# copyright 2010 Edwin Marshall (aspidites) <aspidties@inbox.com>             #
#                                                                             #
# This file is part of MaeGym                                                 #
#                                                                             #
# MaeGym is free software: you can redistribute it and/or                     #
# modify it under the terms of the GNU General Public License as published by #
# the Free Software Foundation, either version 3 of the License, or           #
# (at your option) any later version.                                         #
#                                                                             #
# MaeGym is distributed in the hope that it will be useful,                   #
# but WITHOUT ANY WARRANTY; without even the implied warranty of              #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               #
# GNU General Public License for more details.                                #
#                                                                             #
# You should have received a copy of the GNU General Public License           #
# along with MaeGym.                                                          # 
# If not, see <http://www.gnu.org/licenses/>.                                 #
###############################################################################

# builtin modules
import sys

# pyqt modules
from PyQt4.QtGui import (QApplication, QHBoxLayout, QLabel, QPushButton, 
                         QMainWindow, QVBoxLayout, QWidget) 
from PyQt4.QtCore import (pyqtSignature, Qt)
import sip

# third-party modules
import config as c

# program modules 
from database import Database
from ui.ui_welcome_window import Ui_WelcomeWindow
import exercises_window as ew
import routines_window as ww
import target_areas_window as taw
import meals_window as mw
import settings_dialog as sd

class WelcomeWindow(QMainWindow, Ui_WelcomeWindow):
    def __init__(self, parent=None):
        super(QMainWindow, self).__init__(parent)

        self.setAttribute(Qt.WA_Maemo5StackedWindow, True)

        self.setupUi(self)
        self.db = Database(self)
        self.loadConfigOptions()
        self.reflowWidgets()

        QApplication.desktop().resized.connect(self.reflowWidgets)

    def loadConfigOptions(self):
        self.config = c.Config()
        self.setOrientation()
        self.setFitnessWindow()
        self.setNutritionWindow()

    def setOrientation(self):
        if self.config.interface['orientation'].lower() == 'auto':
            self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
        elif self.config.interface['orientation'].lower() == 'landscape':
            self.setAttribute(Qt.WA_Maemo5LandscapeOrientation, True)
        elif self.config.interface['orientation'].lower() == 'portrait':
            self.setAttribute(Qt.WA_Maemo5PortraitOrientation, True)

    def setFitnessWindow(self):
        if self.config.interface['remember-last-fitness']:
            if self.config.interface['last-fitness'] == 'exercises':
                self.fitness_window = ew.ExercisesWindow(self, self.db)
            elif self.config.interface['last-fitness'] == 'routines':
                self.fitness_window = ww.RoutinesWindow(self, self.db)
            elif self.config.interface['last-fitness'] == 'target_areas':
                self.fitness_window = taw.TargetAreasWindow(self, self.db)
        else:
            self.fitness_window = ew.ExercisesWindow(self, self.db)

    def setNutritionWindow(self):
        self.nutrition_window = mw.MealsWindow(self, self.db)

    def reflowWidgets(self):
        try:
            sip.delete(self.central_widget.layout())
        except TypeError:
            pass

        screen_geometry = QApplication.desktop().screenGeometry()
        if screen_geometry.width() > screen_geometry.height():
            self.central_widget.setLayout(QHBoxLayout())
        else:
            self.central_widget.setLayout(QVBoxLayout())

        self.central_widget.layout().addWidget(self.fitness_button)
        self.central_widget.layout().addWidget(self.nutrition_button)
        self.central_widget.layout().addWidget(self.progress_button)
        self.central_widget.layout().addWidget(self.agenda_button)

    def on_fitness_button_clicked(self):
        self.fitness_window.show()

    def on_nutrition_button_clicked(self):
        self.nutrition_window.show()

    @pyqtSignature("bool")
    def on_settings_action_triggered(self, checked):
        settings_dialog = sd.SettingsDialog(self)
        settings_dialog.show()
    

if __name__ == '__main__':
    app = QApplication(sys.argv)
    app.setApplicationName('MaeGym')
    welcome_window = WelcomeWindow()
    welcome_window.show()
    sys.exit(app.exec_())

==> maegym_0.4.7-1.tar.gz: maegym-0.4.7/src/usr/lib/python2.5/site-packages/maegym/welcome_window.py <==
###############################################################################
# copyright 2010 Edwin Marshall (aspidites) <aspidties@inbox.com>             #
#                                                                             #
# This file is part of MaeGym                                                 #
#                                                                             #
# MaeGym is free software: you can redistribute it and/or                     #
# modify it under the terms of the GNU General Public License as published by #
# the Free Software Foundation, either version 3 of the License, or           #
# (at your option) any later version.                                         #
#                                                                             #
# MaeGym is distributed in the hope that it will be useful,                   #
# but WITHOUT ANY WARRANTY; without even the implied warranty of              #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               #
# GNU General Public License for more details.                                #
#                                                                             #
# You should have received a copy of the GNU General Public License           #
# along with MaeGym.                                                          # 
# If not, see <http://ssw.gnu.org/licenses/>.                                 #
###############################################################################

# builtin modules
import sys

# pyqt modules
from PyQt4.QtGui import (QApplication, QHBoxLayout, QLabel, QPushButton, 
                         QMainWindow, QVBoxLayout, QWidget) 
from PyQt4.QtCore import (pyqtSignature, Qt)
import sip

# third-party modules
import config as c

# program modules 
from database import Database
from ui.ui_welcome_window import Ui_WelcomeWindow
import exercises_window as ew
import sessions_window as ss
import target_areas_window as taw
import meals_window as mw
import settings_dialog as sd

class WelcomeWindow(QMainWindow, Ui_WelcomeWindow):
    def __init__(self, parent=None):
        super(QMainWindow, self).__init__(parent)

        self.setAttribute(Qt.WA_Maemo5StackedWindow, True)

        self.setupUi(self)
        self.db = Database(self)
        self.loadConfigOptions()
        self.reflowWidgets()

        QApplication.desktop().resized.connect(self.reflowWidgets)

    def loadConfigOptions(self):
        self.config = c.Config()
        self.setOrientation()
        self.setFitnessWindow()
        self.setNutritionWindow()

    def setOrientation(self):
        if self.config.interface['orientation'].lower() == 'auto':
            self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
        elif self.config.interface['orientation'].lower() == 'landscape':
            self.setAttribute(Qt.WA_Maemo5LandscapeOrientation, True)
        elif self.config.interface['orientation'].lower() == 'portrait':
            self.setAttribute(Qt.WA_Maemo5PortraitOrientation, True)

    def setFitnessWindow(self):
        if self.config.interface['remember-last-fitness']:
            if self.config.interface['last-fitness'] == 'exercises':
                self.fitness_window = ew.ExercisesWindow(self, self.db)
            elif self.config.interface['last-fitness'] == 'sessions':
                self.fitness_window = ss.SessionsWindow(self, self.db)
            elif self.config.interface['last-fitness'] == 'target_areas':
                self.fitness_window = taw.TargetAreasWindow(self, self.db)
        else:
            self.fitness_window = ew.ExercisesWindow(self, self.db)

    def setNutritionWindow(self):
        self.nutrition_window = mw.MealsWindow(self, self.db)

    def reflowWidgets(self):
        try:
            sip.delete(self.central_widget.layout())
        except TypeError:
            pass

        screen_geometry = QApplication.desktop().screenGeometry()
        if screen_geometry.width() > screen_geometry.height():
            self.central_widget.setLayout(QHBoxLayout())
        else:
            self.central_widget.setLayout(QVBoxLayout())

        self.central_widget.layout().addWidget(self.fitness_button)
        self.central_widget.layout().addWidget(self.nutrition_button)
        self.central_widget.layout().addWidget(self.progress_button)
        self.central_widget.layout().addWidget(self.agenda_button)

    def on_fitness_button_clicked(self):
        self.fitness_window.show()

    def on_nutrition_button_clicked(self):
        self.nutrition_window.show()

    @pyqtSignature("bool")
    def on_settings_action_triggered(self, checked):
        settings_dialog = sd.SettingsDialog(self)
        settings_dialog.show()
    

if __name__ == '__main__':
    app = QApplication(sys.argv)
    app.setApplicationName('MaeGym')
    welcome_window = WelcomeWindow()
    welcome_window.show()
    sys.exit(app.exec_())
